#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_portal.portlets.html.interfaces import IRawPortletSettings, IHTMLPortletSettings
from pyams_utils.interfaces import VIEW_PERMISSION

# import packages
from pyams_portal.portlet import PortletSettings, portlet_config, Portlet
from pyams_utils.factory import factory_config
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty

from pyams_portal import _


#
# Raw HTML code portlet
#

RAW_PORTLET_NAME = 'pyams_portal.portlet.raw'


@implementer(IRawPortletSettings)
@factory_config(provided=IRawPortletSettings)
class RawPortletSettings(PortletSettings):
    """Raw HTML code portlet settings"""

    title = FieldProperty(IRawPortletSettings['title'])
    body = FieldProperty(IRawPortletSettings['body'])


@portlet_config(permission=VIEW_PERMISSION)
class RawPortlet(Portlet):
    """Raw HTML code portlet"""

    name = RAW_PORTLET_NAME
    label = _("Raw HTML")

    toolbar_css_class = 'fa fa-fw fa-2x fa-code'

    settings_factory = IRawPortletSettings


#
# Rich text portlet
#

HTML_PORTLET_NAME = 'pyams_portal.portlet.html'


@implementer(IHTMLPortletSettings)
@factory_config(provided=IHTMLPortletSettings)
class HTMLPortletSettings(PortletSettings):
    """Rich text portlet settings"""

    body = FieldProperty(IHTMLPortletSettings['body'])


@portlet_config(permission=VIEW_PERMISSION)
class HTMLPortlet(Portlet):
    """Rich text portlet"""

    name = HTML_PORTLET_NAME
    label = _("Rich text")

    toolbar_css_class = 'fa fa-fw fa-2x fa-font'

    settings_factory = IHTMLPortletSettings
