#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_form.interfaces.form import IInnerTabForm
from pyams_pagelet.interfaces import IPagelet
from pyams_portal.interfaces import IPortletPreviewer
from pyams_portal.portlets.html.interfaces import IRawPortletSettings, IHTMLPortletSettings
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION

# import packages
from pyams_form.form import AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_portal.portlet import PortletPreviewer
from pyams_portal.zmi.portlet import PortletSettingsEditor, PortletSettingsPropertiesEditor
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from zope.interface import Interface


#
# Raw code portlet properties
#

@pagelet_config(name='properties.html', context=IRawPortletSettings, request_type=IPyAMSLayer,
                permission=VIEW_SYSTEM_PERMISSION)
class RawPortletSettingsEditor(PortletSettingsEditor):
    """Raw HTML portlet settings editor"""

    settings = IRawPortletSettings


@adapter_config(name='properties', context=(Interface, IPyAMSLayer, RawPortletSettingsEditor), provides=IInnerTabForm)
class RawPortletSettingsPropertiesEditor(PortletSettingsPropertiesEditor):
    """Raw portlet settings properties editor"""

    def updateWidgets(self, prefix=None):
        super(RawPortletSettingsPropertiesEditor, self).updateWidgets(prefix)
        if 'body' in self.widgets:
            self.widgets['body'].widget_css_class = 'input height-100'


@adapter_config(name='properties.json', context=(IRawPortletSettings, IPyAMSLayer), provides=IPagelet)
class RawPortletConfigurationAJAXEditor(AJAXEditForm, RawPortletSettingsEditor):
    """Raw HTML portlet settings editor, AJAX renderer"""


@adapter_config(context=(Interface, IPyAMSLayer, Interface, IRawPortletSettings), provides=IPortletPreviewer)
@template_config(template='raw-preview.pt', layer=IPyAMSLayer)
class RawPortletPreviewer(PortletPreviewer):
    """Raw HTML portlet previewer"""


#
# Rich text portlet properties
#

@pagelet_config(name='properties.html', context=IHTMLPortletSettings, request_type=IPyAMSLayer,
                permission=VIEW_SYSTEM_PERMISSION)
class HTMLPortletSettingsEditor(PortletSettingsEditor):
    """Rich text portlet settings editor"""

    settings = IHTMLPortletSettings


@adapter_config(name='properties.json', context=(IHTMLPortletSettings, IPyAMSLayer), provides=IPagelet)
class HTMLPortletConfigurationAJAXEditor(AJAXEditForm, HTMLPortletSettingsEditor):
    """Rich text portlet settings editor, AJAX renderer"""


@adapter_config(context=(Interface, IPyAMSLayer, Interface, IHTMLPortletSettings), provides=IPortletPreviewer)
@template_config(template='html-preview.pt', layer=IPyAMSLayer)
class HTMLPortletPreviewer(PortletPreviewer):
    """Rich text portlet previewer"""
